@@ -43,12 +43,12 @@ run_atos <- function(X, y, groups, groupIDs, pen_slope, pen_gslope, x0, u, wt, n
     Xbeta = mult_fcn(X,z)
     fz = f(y, Xbeta, num_obs, crossprod_mat)
     grad_fz = mult_fcn(tX,f_grad(y, Xbeta, num_obs))
-    x = sortedL1Prox(x=z - (step_size * (u + (grad_fz))), lambda=pen_slope*step_size, method="stack")
+    x = sortedL1Prox(x=z - (step_size * (u + (grad_fz))), lambda=pen_slope*step_size)
     incr = x - z
     norm_incr = norm_vec(incr)
     if (norm_incr > 1e-7){
       for (it_ls in 1:max_iter_backtracking){ # Line search
-        x = sortedL1Prox(x=z - (step_size * (u + (grad_fz))), lambda=pen_slope*step_size, method="stack")
+        x = sortedL1Prox(x=z - (step_size * (u + (grad_fz))), lambda=pen_slope*step_size)
         incr = x - z
         norm_incr = norm_vec(incr)
         rhs = fz + crossprod_mat(grad_fz,incr) + (norm_incr ^ 2) / (2 * step_size)
